import OCP.BRepMAT2d
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import io
import OCP.TColGeom2d
import OCP.gp
import OCP.MAT
import OCP.TopoDS
import OCP.TColStd
import OCP.Bisector
import OCP.Geom2d
import OCP.NCollection
__all__  = [
"BRepMAT2d_BisectingLocus",
"BRepMAT2d_DataMapOfBasicEltShape",
"BRepMAT2d_DataMapOfShapeSequenceOfBasicElt",
"BRepMAT2d_Explorer",
"BRepMAT2d_LinkTopoBilo"
]
class BRepMAT2d_BisectingLocus():
    """
    BisectingLocus generates and contains the Bisecting_Locus of a set of lines from Geom2d, defined by <ExploSet>.
    """
    def BasicElt(self,IndLine : int,Index : int) -> OCP.MAT.MAT_BasicElt: 
        """
        Returns the BasicElts located at the position <Index> on the contour designed by <IndLine>. Remark: the BasicElts on a contour are sorted.
        """
    def Compute(self,anExplo : BRepMAT2d_Explorer,LineIndex : int=1,aSide : OCP.MAT.MAT_Side=MAT_Side.MAT_Left,aJoinType : OCP.GeomAbs.GeomAbs_JoinType=GeomAbs_JoinType.GeomAbs_Arc,IsOpenResult : bool=False) -> None: 
        """
        Computation of the Bisector_Locus in a set of Lines defined in <anExplo>. The bisecting locus are computed on the side <aSide> from the line <LineIndex> in <anExplo>.
        """
    def GeomBis(self,anArc : OCP.MAT.MAT_Arc,Reverse : bool) -> OCP.Bisector.Bisector_Bisec: 
        """
        Returns the geometry of type <Bissec> linked to the arc <ARC>. <Reverse> is False when the FirstNode of <anArc> correspond to the first point of geometry.
        """
    @overload
    def GeomElt(self,aBasicElt : OCP.MAT.MAT_BasicElt) -> OCP.Geom2d.Geom2d_Geometry: 
        """
        Returns the geometry linked to the <BasicElt>.

        Returns the geometry of type <gp> linked to the <Node>.
        """
    @overload
    def GeomElt(self,aNode : OCP.MAT.MAT_Node) -> OCP.gp.gp_Pnt2d: ...
    def Graph(self) -> OCP.MAT.MAT_Graph: 
        """
        Returns <theGraph> of <me>.
        """
    def IsDone(self) -> bool: 
        """
        Returns True if Compute has succeeded.
        """
    def NumberOfContours(self) -> int: 
        """
        Returns the number of contours.
        """
    def NumberOfElts(self,IndLine : int) -> int: 
        """
        Returns the number of BasicElts on the line <IndLine>.
        """
    def NumberOfSections(self,IndLine : int,Index : int) -> int: 
        """
        Returns the number of sections of a curve. this curve is the Indexth curve in the IndLineth contour given by anExplo.
        """
    def __init__(self) -> None: ...
    pass
class BRepMAT2d_DataMapOfBasicEltShape(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: The DataMap is a Map to store keys with associated Items. See Map from NCollection for a discussion about the number of buckets.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : BRepMAT2d_DataMapOfBasicEltShape) -> BRepMAT2d_DataMapOfBasicEltShape: 
        """
        Assignment. This method does not change the internal allocator.
        """
    def Bind(self,theKey : OCP.MAT.MAT_BasicElt,theItem : OCP.TopoDS.TopoDS_Shape) -> bool: 
        """
        Bind binds Item to Key in map.
        """
    def Bound(self,theKey : OCP.MAT.MAT_BasicElt,theItem : OCP.TopoDS.TopoDS_Shape) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Bound binds Item to Key in map.
        """
    def ChangeFind(self,theKey : OCP.MAT.MAT_BasicElt) -> OCP.TopoDS.TopoDS_Shape: 
        """
        ChangeFind returns mofifiable Item by Key. Raises if Key was not bound
        """
    def ChangeSeek(self,theKey : OCP.MAT.MAT_BasicElt) -> OCP.TopoDS.TopoDS_Shape: 
        """
        ChangeSeek returns modifiable pointer to Item by Key. Returns NULL is Key was not bound.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    def Exchange(self,theOther : BRepMAT2d_DataMapOfBasicEltShape) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    @overload
    def Find(self,theKey : OCP.MAT.MAT_BasicElt) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Find returns the Item for Key. Raises if Key was not bound

        Find Item for key with copying.
        """
    @overload
    def Find(self,theKey : OCP.MAT.MAT_BasicElt,theValue : OCP.TopoDS.TopoDS_Shape) -> bool: ...
    def IsBound(self,theKey : OCP.MAT.MAT_BasicElt) -> bool: 
        """
        IsBound
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Seek(self,theKey : OCP.MAT.MAT_BasicElt) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Seek returns pointer to Item by Key. Returns NULL is Key was not bound.
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def UnBind(self,theKey : OCP.MAT.MAT_BasicElt) -> bool: 
        """
        UnBind removes Item Key pair from map
        """
    def __call__(self,theKey : OCP.MAT.MAT_BasicElt) -> OCP.TopoDS.TopoDS_Shape: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : BRepMAT2d_DataMapOfBasicEltShape) -> None: ...
    def __iter__(self) -> Iterator[OCP.TopoDS.TopoDS_Shape]: ...
    def __len__(self) -> int: ...
    pass
class BRepMAT2d_DataMapOfShapeSequenceOfBasicElt(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: The DataMap is a Map to store keys with associated Items. See Map from NCollection for a discussion about the number of buckets.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : BRepMAT2d_DataMapOfShapeSequenceOfBasicElt) -> BRepMAT2d_DataMapOfShapeSequenceOfBasicElt: 
        """
        Assignment. This method does not change the internal allocator.
        """
    def Bind(self,theKey : OCP.TopoDS.TopoDS_Shape,theItem : OCP.MAT.MAT_SequenceOfBasicElt) -> bool: 
        """
        Bind binds Item to Key in map.
        """
    def Bound(self,theKey : OCP.TopoDS.TopoDS_Shape,theItem : OCP.MAT.MAT_SequenceOfBasicElt) -> OCP.MAT.MAT_SequenceOfBasicElt: 
        """
        Bound binds Item to Key in map.
        """
    def ChangeFind(self,theKey : OCP.TopoDS.TopoDS_Shape) -> OCP.MAT.MAT_SequenceOfBasicElt: 
        """
        ChangeFind returns mofifiable Item by Key. Raises if Key was not bound
        """
    def ChangeSeek(self,theKey : OCP.TopoDS.TopoDS_Shape) -> OCP.MAT.MAT_SequenceOfBasicElt: 
        """
        ChangeSeek returns modifiable pointer to Item by Key. Returns NULL is Key was not bound.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    def Exchange(self,theOther : BRepMAT2d_DataMapOfShapeSequenceOfBasicElt) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    @overload
    def Find(self,theKey : OCP.TopoDS.TopoDS_Shape) -> OCP.MAT.MAT_SequenceOfBasicElt: 
        """
        Find returns the Item for Key. Raises if Key was not bound

        Find Item for key with copying.
        """
    @overload
    def Find(self,theKey : OCP.TopoDS.TopoDS_Shape,theValue : OCP.MAT.MAT_SequenceOfBasicElt) -> bool: ...
    def IsBound(self,theKey : OCP.TopoDS.TopoDS_Shape) -> bool: 
        """
        IsBound
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Seek(self,theKey : OCP.TopoDS.TopoDS_Shape) -> OCP.MAT.MAT_SequenceOfBasicElt: 
        """
        Seek returns pointer to Item by Key. Returns NULL is Key was not bound.
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def UnBind(self,theKey : OCP.TopoDS.TopoDS_Shape) -> bool: 
        """
        UnBind removes Item Key pair from map
        """
    def __call__(self,theKey : OCP.TopoDS.TopoDS_Shape) -> OCP.MAT.MAT_SequenceOfBasicElt: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : BRepMAT2d_DataMapOfShapeSequenceOfBasicElt) -> None: ...
    def __iter__(self) -> Iterator[OCP.MAT.MAT_SequenceOfBasicElt]: ...
    def __len__(self) -> int: ...
    pass
class BRepMAT2d_Explorer():
    """
    Construct an explorer from wires, face, set of curves from Geom2d to compute the bisecting Locus.
    """
    def Clear(self) -> None: 
        """
        Clear the contents of <me>.
        """
    def Contour(self,IndexContour : int) -> OCP.TColGeom2d.TColGeom2d_SequenceOfCurve: ...
    def GetIsClosed(self) -> OCP.TColStd.TColStd_SequenceOfBoolean: ...
    def Init(self,IndexContour : int) -> None: 
        """
        Initialisation of an Iterator on the curves of the Contour number <IndexContour>.
        """
    def IsModified(self,aShape : OCP.TopoDS.TopoDS_Shape) -> bool: ...
    def ModifiedShape(self,aShape : OCP.TopoDS.TopoDS_Shape) -> OCP.TopoDS.TopoDS_Shape: 
        """
        If the shape is not modified, returns the shape itself.
        """
    def More(self) -> bool: 
        """
        Return False if there is no more curves on the Contour initialised by the method Init.
        """
    def Next(self) -> None: 
        """
        Move to the next curve of the current Contour.
        """
    def NumberOfContours(self) -> int: 
        """
        Returns the Number of contours.
        """
    def NumberOfCurves(self,IndexContour : int) -> int: 
        """
        Returns the Number of Curves in the Contour number <IndexContour>.
        """
    def Perform(self,aFace : OCP.TopoDS.TopoDS_Face) -> None: ...
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: ...
    def Value(self) -> OCP.Geom2d.Geom2d_Curve: 
        """
        Returns the current curve on the current Contour.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,aFace : OCP.TopoDS.TopoDS_Face) -> None: ...
    pass
class BRepMAT2d_LinkTopoBilo():
    """
    Constructs links between the Wire or the Face of the explorer and the BasicElts contained in the bisecting locus.
    """
    def GeneratingShape(self,aBE : OCP.MAT.MAT_BasicElt) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns the Shape linked to <aBE>.
        """
    def Init(self,S : OCP.TopoDS.TopoDS_Shape) -> None: 
        """
        Initialise the Iterator on <S> <S> is an edge or a vertex of the initial wire or face. raises if <S> is not an edge or a vertex.
        """
    def More(self) -> bool: 
        """
        Returns True if there is a current BasicElt.
        """
    def Next(self) -> None: 
        """
        Proceed to the next BasicElt.
        """
    def Perform(self,Explo : BRepMAT2d_Explorer,BiLo : BRepMAT2d_BisectingLocus) -> None: 
        """
        Constructs the links Between S and BiLo.
        """
    def Value(self) -> OCP.MAT.MAT_BasicElt: 
        """
        Returns the current BasicElt.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Explo : BRepMAT2d_Explorer,BiLo : BRepMAT2d_BisectingLocus) -> None: ...
    pass



import OCP
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
__all__  = [
"AIS",
"APIHeaderSection",
"Adaptor2d",
"Adaptor3d",
"AdvApp2Var",
"AdvApprox",
"AppBlend",
"AppCont",
"AppDef",
"AppParCurves",
"AppStd",
"AppStdL",
"Approx",
"Aspect",
"BOPAlgo",
"BOPDS",
"BOPTools",
"BRep",
"BRepAdaptor",
"BRepAlgo",
"BRepAlgoAPI",
"BRepApprox",
"BRepBlend",
"BRepBndLib",
"BRepBuilderAPI",
"BRepCheck",
"BRepClass",
"BRepClass3d",
"BRepExtrema",
"BRepFeat",
"BRepFill",
"BRepFilletAPI",
"BRepGProp",
"BRepIntCurveSurface",
"BRepLProp",
"BRepLib",
"BRepMAT2d",
"BRepMesh",
"BRepOffset",
"BRepOffsetAPI",
"BRepPrim",
"BRepPrimAPI",
"BRepProj",
"BRepSweep",
"BRepToIGES",
"BRepToIGESBRep",
"BRepTools",
"BRepTopAdaptor",
"BSplCLib",
"BSplSLib",
"BVH",
"BiTgte",
"BinDrivers",
"BinLDrivers",
"BinMDF",
"BinMDataStd",
"BinMDataXtd",
"BinMDocStd",
"BinMFunction",
"BinMNaming",
"BinObjMgt",
"BinTObjDrivers",
"BinTools",
"BinXCAFDrivers",
"Bisector",
"Blend",
"BlendFunc",
"Bnd",
"BndLib",
"CDF",
"CDM",
"CPnts",
"CSLib",
"ChFi2d",
"ChFi3d",
"ChFiDS",
"Contap",
"Convert",
"DE",
"Draft",
"DsgPrs",
"ElCLib",
"ElSLib",
"Expr",
"ExprIntrp",
"Extrema",
"FEmTool",
"FSD",
"FairCurve",
"FilletSurf",
"Font",
"GC",
"GCE2d",
"GCPnts",
"GProp",
"GccAna",
"GccEnt",
"GccInt",
"Geom",
"Geom2d",
"Geom2dAPI",
"Geom2dAdaptor",
"Geom2dConvert",
"Geom2dEvaluator",
"Geom2dGcc",
"Geom2dHatch",
"Geom2dInt",
"Geom2dLProp",
"Geom2dToIGES",
"GeomAPI",
"GeomAbs",
"GeomAdaptor",
"GeomConvert",
"GeomEvaluator",
"GeomFill",
"GeomInt",
"GeomLProp",
"GeomLib",
"GeomPlate",
"GeomProjLib",
"GeomToIGES",
"GeomToStep",
"GeomTools",
"Graphic3d",
"HLRAlgo",
"HLRAppli",
"HLRBRep",
"HLRTopoBRep",
"Hatch",
"HatchGen",
"Hermit",
"IFGraph",
"IFSelect",
"IGESAppli",
"IGESBasic",
"IGESCAFControl",
"IGESControl",
"IGESConvGeom",
"IGESData",
"IGESDefs",
"IGESDimen",
"IGESDraw",
"IGESFile",
"IGESGeom",
"IGESGraph",
"IGESSelect",
"IGESSolid",
"IGESToBRep",
"IMeshData",
"IMeshTools",
"IVtk",
"IVtkOCC",
"IVtkTools",
"IVtkVTK",
"Image",
"IntAna",
"IntAna2d",
"IntCurve",
"IntCurveSurface",
"IntCurvesFace",
"IntImp",
"IntImpParGen",
"IntPatch",
"IntPolyh",
"IntRes2d",
"IntStart",
"IntSurf",
"IntTools",
"Interface",
"InterfaceGraphic",
"Intf",
"Intrv",
"LDOM",
"LProp",
"LProp3d",
"Law",
"LocOpe",
"LocalAnalysis",
"MAT",
"MAT2d",
"MeshVS",
"Message",
"NCollection",
"NIS",
"NLPlate",
"OSD",
"OpenGl",
"PCDM",
"PLib",
"Plate",
"Plugin",
"Poly",
"Precision",
"ProjLib",
"Prs3d",
"PrsMgr",
"Quantity",
"RWGltf",
"RWMesh",
"RWStepAP203",
"RWStepAP214",
"RWStepAP242",
"RWStepBasic",
"RWStepDimTol",
"RWStepElement",
"RWStepFEA",
"RWStepGeom",
"RWStepRepr",
"RWStepShape",
"RWStepVisual",
"RWStl",
"Resource",
"STEPCAFControl",
"STEPConstruct",
"STEPControl",
"STEPEdit",
"STEPSelections",
"Select3D",
"SelectBasics",
"SelectMgr",
"ShapeAlgo",
"ShapeAnalysis",
"ShapeBuild",
"ShapeConstruct",
"ShapeCustom",
"ShapeExtend",
"ShapeFix",
"ShapeProcess",
"ShapeProcessAPI",
"ShapeUpgrade",
"Standard",
"StdDrivers",
"StdFail",
"StdLDrivers",
"StdLPersistent",
"StdObjMgt",
"StdObject",
"StdPersistent",
"StdPrs",
"StdSelect",
"StdStorage",
"StepAP203",
"StepAP209",
"StepAP214",
"StepAP242",
"StepBasic",
"StepData",
"StepDimTol",
"StepElement",
"StepFEA",
"StepGeom",
"StepRepr",
"StepShape",
"StepToGeom",
"StepToTopoDS",
"StepVisual",
"StlAPI",
"Storage",
"Sweep",
"TColGeom",
"TColGeom2d",
"TColStd",
"TColgp",
"TCollection",
"TDF",
"TDataStd",
"TDataXtd",
"TDocStd",
"TFunction",
"TNaming",
"TObj",
"TPrsStd",
"TShort",
"TopAbs",
"TopBas",
"TopClass",
"TopCnx",
"TopExp",
"TopLoc",
"TopOpeBRep",
"TopOpeBRepBuild",
"TopOpeBRepDS",
"TopOpeBRepTool",
"TopTools",
"TopTrans",
"TopoDS",
"TopoDSToStep",
"Transfer",
"UTL",
"Units",
"UnitsAPI",
"UnitsMethods",
"V3d",
"Voxel",
"Vrml",
"VrmlAPI",
"XBRepMesh",
"XCAFApp",
"XCAFDimTolObjects",
"XCAFDoc",
"XCAFNoteObjects",
"XCAFPrs",
"XCAFView",
"XSControl",
"XmlDrivers",
"XmlLDrivers",
"XmlMDF",
"XmlMDataStd",
"XmlMDataXtd",
"XmlMDocStd",
"XmlMFunction",
"XmlMNaming",
"XmlObjMgt",
"XmlTObjDrivers",
"XmlXCAFDrivers",
"Xw",
"gce",
"gp",
"math",
"__version__"
]
__version__ = '7.9.3.1'



import OCP.AppCont
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.AppParCurves
import OCP.TColgp
__all__  = [
"AppCont_Function",
"AppCont_LeastSquare",
"PeriodicityInfo"
]
class AppCont_Function():
    """
    Class describing a continuous 3d and/or function f(u). This class must be provided by the user to use the approximation algorithm FittingCurve.
    """
    def D1(self,theU : float,theVec2d : OCP.TColgp.TColgp_Array1OfVec2d,theVec : OCP.TColgp.TColgp_Array1OfVec) -> bool: 
        """
        Returns the derivative at parameter <theU>.
        """
    def FirstParameter(self) -> float: 
        """
        Returns the first parameter of the function.
        """
    def GetNbOf2dPoints(self) -> int: 
        """
        Get number of 2d points returned by "Value" and "D1" functions.
        """
    def GetNbOf3dPoints(self) -> int: 
        """
        Get number of 3d points returned by "Value" and "D1" functions.
        """
    def GetNumberOfPoints(self) -> tuple[int, int]: 
        """
        Get number of 3d and 2d points returned by "Value" and "D1" functions.
        """
    def LastParameter(self) -> float: 
        """
        Returns the last parameter of the function.
        """
    def Value(self,theU : float,thePnt2d : OCP.TColgp.TColgp_Array1OfPnt2d,thePnt : OCP.TColgp.TColgp_Array1OfPnt) -> bool: 
        """
        Returns the point at parameter <theU>.
        """
    def __init__(self) -> None: ...
    pass
class AppCont_LeastSquare():
    def Error(self) -> tuple[float, float, float]: ...
    def IsDone(self) -> bool: ...
    def Value(self) -> OCP.AppParCurves.AppParCurves_MultiCurve: ...
    def __init__(self,SSP : AppCont_Function,U0 : float,U1 : float,FirstCons : OCP.AppParCurves.AppParCurves_Constraint,LastCons : OCP.AppParCurves.AppParCurves_Constraint,Deg : int,NbPoints : int) -> None: ...
    pass
class PeriodicityInfo():
    def __init__(self) -> None: ...
    @property
    def isPeriodic(self) -> bool:
        """
        :type: bool
        """
    @isPeriodic.setter
    def isPeriodic(self, arg0: bool) -> None:
        pass
    @property
    def myPeriod(self) -> float:
        """
        :type: float
        """
    @myPeriod.setter
    def myPeriod(self, arg0: float) -> None:
        pass
    pass



import OCP.CDM
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.Resource
import OCP.TColStd
import OCP.Message
import OCP.Standard
import OCP.NCollection
__all__  = [
"CDM_Application",
"CDM_CanCloseStatus",
"CDM_Document",
"CDM_ListOfDocument",
"CDM_ListOfReferences",
"CDM_MapOfDocument",
"CDM_MetaData",
"CDM_Reference",
"CDM_ReferenceIterator",
"CDM_CCS_ModifiedReferenced",
"CDM_CCS_NotOpen",
"CDM_CCS_OK",
"CDM_CCS_ReferenceRejection",
"CDM_CCS_UnstoredReferenced"
]
class CDM_Application(OCP.Standard.Standard_Transient):
    def BeginOfUpdate(self,aDocument : CDM_Document) -> None: 
        """
        this method is called before the update of a document. By default, writes in MessageDriver().
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def EndOfUpdate(self,aDocument : CDM_Document,theStatus : bool,ErrorString : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        this method is called after the update of a document. By default, writes in MessageDriver().
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def MessageDriver(self) -> OCP.Message.Message_Messenger: 
        """
        Returns default messenger;
        """
    def MetaDataLookUpTable(self) -> Any: 
        """
        Returns MetaData LookUpTable
        """
    def Name(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Returns the application name.
        """
    def Resources(self) -> OCP.Resource.Resource_Manager: 
        """
        The manager returned by this virtual method will be used to search for Format.Retrieval resource items.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Version(self) -> OCP.TCollection.TCollection_AsciiString: 
        """
        Returns the application version.
        """
    def Write(self,aString : str) -> None: 
        """
        writes the string in the application MessagerDriver.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDM_CanCloseStatus():
    """
    Members:

      CDM_CCS_OK

      CDM_CCS_NotOpen

      CDM_CCS_UnstoredReferenced

      CDM_CCS_ModifiedReferenced

      CDM_CCS_ReferenceRejection
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    CDM_CCS_ModifiedReferenced: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_ModifiedReferenced: 3>
    CDM_CCS_NotOpen: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_NotOpen: 1>
    CDM_CCS_OK: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_OK: 0>
    CDM_CCS_ReferenceRejection: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_ReferenceRejection: 4>
    CDM_CCS_UnstoredReferenced: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_UnstoredReferenced: 2>
    __entries: dict # value = {'CDM_CCS_OK': (<CDM_CanCloseStatus.CDM_CCS_OK: 0>, None), 'CDM_CCS_NotOpen': (<CDM_CanCloseStatus.CDM_CCS_NotOpen: 1>, None), 'CDM_CCS_UnstoredReferenced': (<CDM_CanCloseStatus.CDM_CCS_UnstoredReferenced: 2>, None), 'CDM_CCS_ModifiedReferenced': (<CDM_CanCloseStatus.CDM_CCS_ModifiedReferenced: 3>, None), 'CDM_CCS_ReferenceRejection': (<CDM_CanCloseStatus.CDM_CCS_ReferenceRejection: 4>, None)}
    __members__: dict # value = {'CDM_CCS_OK': <CDM_CanCloseStatus.CDM_CCS_OK: 0>, 'CDM_CCS_NotOpen': <CDM_CanCloseStatus.CDM_CCS_NotOpen: 1>, 'CDM_CCS_UnstoredReferenced': <CDM_CanCloseStatus.CDM_CCS_UnstoredReferenced: 2>, 'CDM_CCS_ModifiedReferenced': <CDM_CanCloseStatus.CDM_CCS_ModifiedReferenced: 3>, 'CDM_CCS_ReferenceRejection': <CDM_CanCloseStatus.CDM_CCS_ReferenceRejection: 4>}
    pass
class CDM_Document(OCP.Standard.Standard_Transient):
    """
    An applicative document is an instance of a class inheriting CDM_Document. These documents have the following properties: - they can have references to other documents. - the modifications of a document are propagated to the referencing documents. - a document can be stored in different formats, with or without a persistent model. - the drivers for storing and retrieving documents are plugged in when necessary. - a document has a modification counter. This counter is incremented when the document is modified. When a document is stored, the current counter value is memorized as the last storage version of the document. A document is considered to be modified when the counter value is different from the storage version. Once the document is saved the storage version and the counter value are identical. The document is now not considered to be modified. - a reference is a link between two documents. A reference has two components: the "From Document" and the "To Document". When a reference is created, an identifier of the reference is generated. This identifier is unique in the scope of the From Document and is conserved during storage and retrieval. This means that the referenced document will be always accessible through this identifier. - a reference memorizes the counter value of the To Document when the reference is created. The From Document is considered to be up to date relative to the To Document when the reference counter value is equal to the To Document counter value. - retrieval of a document having references does not imply the retrieving of the referenced documents.An applicative document is an instance of a class inheriting CDM_Document. These documents have the following properties: - they can have references to other documents. - the modifications of a document are propagated to the referencing documents. - a document can be stored in different formats, with or without a persistent model. - the drivers for storing and retrieving documents are plugged in when necessary. - a document has a modification counter. This counter is incremented when the document is modified. When a document is stored, the current counter value is memorized as the last storage version of the document. A document is considered to be modified when the counter value is different from the storage version. Once the document is saved the storage version and the counter value are identical. The document is now not considered to be modified. - a reference is a link between two documents. A reference has two components: the "From Document" and the "To Document". When a reference is created, an identifier of the reference is generated. This identifier is unique in the scope of the From Document and is conserved during storage and retrieval. This means that the referenced document will be always accessible through this identifier. - a reference memorizes the counter value of the To Document when the reference is created. The From Document is considered to be up to date relative to the To Document when the reference counter value is equal to the To Document counter value. - retrieval of a document having references does not imply the retrieving of the referenced documents.An applicative document is an instance of a class inheriting CDM_Document. These documents have the following properties: - they can have references to other documents. - the modifications of a document are propagated to the referencing documents. - a document can be stored in different formats, with or without a persistent model. - the drivers for storing and retrieving documents are plugged in when necessary. - a document has a modification counter. This counter is incremented when the document is modified. When a document is stored, the current counter value is memorized as the last storage version of the document. A document is considered to be modified when the counter value is different from the storage version. Once the document is saved the storage version and the counter value are identical. The document is now not considered to be modified. - a reference is a link between two documents. A reference has two components: the "From Document" and the "To Document". When a reference is created, an identifier of the reference is generated. This identifier is unique in the scope of the From Document and is conserved during storage and retrieval. This means that the referenced document will be always accessible through this identifier. - a reference memorizes the counter value of the To Document when the reference is created. The From Document is considered to be up to date relative to the To Document when the reference counter value is equal to the To Document counter value. - retrieval of a document having references does not imply the retrieving of the referenced documents.
    """
    def AddComment(self,aComment : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        appends a comment into comments of this document.
        """
    def Application(self) -> CDM_Application: ...
    def CanClose(self) -> CDM_CanCloseStatus: ...
    def CanCloseReference(self,aDocument : CDM_Document,aReferenceIdentifier : int) -> bool: 
        """
        A referenced document may indicate through this virtual method that it does not allow the closing of aDocument which it references through the reference aReferenceIdentifier. By default returns Standard_True.
        """
    def Close(self) -> None: ...
    def CloseReference(self,aDocument : CDM_Document,aReferenceIdentifier : int) -> None: 
        """
        A referenced document may update its internal data structure when {aDocument} which it references through the reference {aReferenceIdentifier} is being closed. By default this method does nothing.
        """
    def Comment(self) -> str: 
        """
        Returns the first of associated comments. By default the comment is an empty string.
        """
    def Comments(self,aComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: 
        """
        returns the associated comments through <aComments>. Returns empty sequence if no comments are associated.
        """
    def CopyReference(self,aFromDocument : CDM_Document,aReferenceIdentifier : int) -> int: 
        """
        Copies a reference to this document. This method avoid retrieval of referenced document. The arguments are the original document and a valid reference identifier Returns the local identifier.
        """
    @overload
    def CreateReference(self,anOtherDocument : CDM_Document) -> int: 
        """
        Creates a reference from this document to {anOtherDocument}. Returns a reference identifier. This reference identifier is unique in the document and will not be used for the next references, even after the storing of the document. If there is already a reference between the two documents, the reference is not created, but its reference identifier is returned.
        """
    @overload
    def CreateReference(self,aMetaData : CDM_MetaData,aReferenceIdentifier : int,anApplication : CDM_Application,aToDocumentVersion : int,UseStorageConfiguration : bool) -> None: ...
    @overload
    def CreateReference(self,aMetaData : CDM_MetaData,anApplication : CDM_Application,aDocumentVersion : int,UseStorageConfiguration : bool) -> int: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def DeepReferences(self,aDocument : CDM_Document) -> bool: 
        """
        returns True is this document references aDocument;
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Description(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        gets the `FileFormat`.Description resource.
        """
    def Document(self,aReferenceIdentifier : int) -> CDM_Document: 
        """
        Returns the To Document of the reference identified by aReferenceIdentifier. If the ToDocument is stored and has not yet been retrieved, this method will retrieve it.
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Extensions(self,Extensions : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: 
        """
        by default empties the extensions.
        """
    def FileExtension(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        gets the Desktop.Domain.Application.`FileFormat`.FileExtension resource.
        """
    def FindDescription(self) -> bool: ...
    def FindFileExtension(self) -> bool: ...
    def Folder(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def FromReferencesNumber(self) -> int: 
        """
        returns the number of references having this document as To Document.
        """
    def GetAlternativeDocument(self,aFormat : OCP.TCollection.TCollection_ExtendedString,anAlternativeDocument : CDM_Document) -> bool: 
        """
        This method can be redefined to extract another document in a different format. For example, to extract a Shape from an applicative document.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasRequestedFolder(self) -> bool: ...
    def HasRequestedPreviousVersion(self) -> bool: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsInSession(self,aReferenceIdentifier : int) -> bool: 
        """
        returns True if the To Document of the reference identified by aReferenceIdentifier is in session, False if it corresponds to a not yet retrieved document.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsModified(self) -> bool: 
        """
        returns true if the version is greater than the storage version
        """
    @overload
    def IsOpened(self) -> bool: 
        """
        returns true if the document corresponding to the given reference has been retrieved and opened. Otherwise returns false. This method does not retrieve the referenced document
        """
    @overload
    def IsOpened(self,aReferenceIdentifier : int) -> bool: ...
    @overload
    def IsReadOnly(self) -> bool: 
        """
        indicates that this document cannot be modified.

        indicates that the referenced document cannot be modified,
        """
    @overload
    def IsReadOnly(self,aReferenceIdentifier : int) -> bool: ...
    @overload
    def IsStored(self,aReferenceIdentifier : int) -> bool: 
        """
        returns True if the To Document of the reference identified by aReferenceIdentifier has already been stored, False otherwise.
        """
    @overload
    def IsStored(self) -> bool: ...
    def IsUpToDate(self,aReferenceIdentifier : int) -> bool: 
        """
        returns true if the modification counter found in the given reference is equal to the actual modification counter of the To Document. This method is able to deal with a reference to a not retrieved document.
        """
    def LoadResources(self) -> None: ...
    def MetaData(self) -> CDM_MetaData: ...
    def Modifications(self) -> int: 
        """
        returns the current modification counter.
        """
    def Modify(self) -> None: 
        """
        Indicates that this document has been modified. This method increments the modification counter.
        """
    def Name(self,aReferenceIdentifier : int) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        returns the name of the metadata of the To Document of the reference identified by aReferenceIdentifier.
        """
    def Open(self,anApplication : CDM_Application) -> None: ...
    def Print(self,anOStream : io.BytesIO) -> io.BytesIO: ...
    def Reference(self,aReferenceIdentifier : int) -> CDM_Reference: ...
    def ReferenceCounter(self) -> int: ...
    def RemoveAllReferences(self) -> None: 
        """
        Removes all references having this document for From Document.
        """
    def RemoveReference(self,aReferenceIdentifier : int) -> None: 
        """
        Removes the reference between the From Document and the To Document identified by a reference identifier.
        """
    def RequestedComment(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def RequestedFolder(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def RequestedName(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        Determines under which the document is going to be store. By default the name of the document will be used. If the document has no name its presentation will be used.
        """
    def RequestedPreviousVersion(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def SetComment(self,aComment : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        associates a comment with this document.
        """
    def SetComments(self,aComments : OCP.TColStd.TColStd_SequenceOfExtendedString) -> None: 
        """
        associates a comments with this document.
        """
    def SetIsReadOnly(self) -> None: ...
    def SetIsUpToDate(self,aReferenceIdentifier : int) -> None: 
        """
        Resets the modification counter in the given reference to the actual modification counter of its To Document. This method should be called after the application has updated this document.
        """
    def SetMetaData(self,aMetaData : CDM_MetaData) -> None: 
        """
        associates database information to a document which has been stored. The name of the document is now the name which has beenused to store the data.
        """
    def SetModifications(self,Modifications : int) -> None: ...
    def SetReferenceCounter(self,aReferenceCounter : int) -> None: ...
    def SetRequestedComment(self,aComment : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        defines the Comment with which the object should be stored.
        """
    def SetRequestedFolder(self,aFolder : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        defines the folder in which the object should be stored.
        """
    def SetRequestedName(self,aName : OCP.TCollection.TCollection_ExtendedString) -> None: 
        """
        defines the name under which the object should be stored.
        """
    def SetRequestedPreviousVersion(self,aPreviousVersion : OCP.TCollection.TCollection_ExtendedString) -> None: ...
    def ShallowReferences(self,aDocument : CDM_Document) -> bool: 
        """
        returns True is this document references aDocument;
        """
    def StorageFormat(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        The Storage Format is the key which is used to determine in the application resources the storage driver plugin, the file extension and other data used to store the document.
        """
    def StorageVersion(self) -> int: 
        """
        returns the value of the modification counter at the time of storage. By default returns 0.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToReferencesNumber(self) -> int: 
        """
        returns the number of references having this document as From Document.
        """
    def UnModify(self) -> None: ...
    def UnsetIsReadOnly(self) -> None: ...
    def UnsetIsStored(self) -> None: ...
    def UnsetRequestedPreviousVersion(self) -> None: ...
    @overload
    def Update(self,aToDocument : CDM_Document,aReferenceIdentifier : int,aModifContext : capsule) -> None: 
        """
        The Update method will be called once for each reference, but it should not perform any computation, to avoid multiple computation of a same document.

        This method Update will be called to signal the end of the modified references list. The document should be recomputed and UpdateFromDocuments should be called. Update should returns True in case of success, false otherwise. In case of Failure, additional information can be given in ErrorString.

        the following method should be used instead:
        """
    @overload
    def Update(self,ErrorString : OCP.TCollection.TCollection_ExtendedString) -> bool: ...
    @overload
    def Update(self) -> None: ...
    def UpdateFromDocuments(self,aModifContext : capsule) -> None: 
        """
        call virtual method Update on all referencing documents. This method keeps the list of the -- documents to process.It may be the starting of an update -- cycle. If not, the reentrant calls made by Update method (without argument) will append the referencing documents to the list and call the Update method (with arguments). Only the first call to UpdateFromDocuments generate call to Update().
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDM_ListOfDocument(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : CDM_Document) -> CDM_Document: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : CDM_Document,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : CDM_ListOfDocument) -> None: ...
    def Assign(self,theOther : CDM_ListOfDocument) -> CDM_ListOfDocument: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> CDM_Document: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : CDM_Document,theIter : Any) -> CDM_Document: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : CDM_ListOfDocument,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : CDM_Document,theIter : Any) -> CDM_Document: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : CDM_ListOfDocument,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> CDM_Document: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : CDM_Document) -> CDM_Document: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : CDM_ListOfDocument) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : CDM_ListOfDocument) -> None: ...
    def __iter__(self) -> Iterator[CDM_Document]: ...
    def __len__(self) -> int: ...
    pass
class CDM_ListOfReferences(OCP.NCollection.NCollection_BaseList):
    """
    Purpose: Simple list to link items together keeping the first and the last one. Inherits BaseList, adding the data item to each node.
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : CDM_Reference) -> CDM_Reference: 
        """
        Append one item at the end

        Append one item at the end and output iterator pointing at the appended item

        Append another list at the end. After this operation, theOther list will be cleared.
        """
    @overload
    def Append(self,theItem : CDM_Reference,theIter : Any) -> None: ...
    @overload
    def Append(self,theOther : CDM_ListOfReferences) -> None: ...
    def Assign(self,theOther : CDM_ListOfReferences) -> CDM_ListOfReferences: 
        """
        Replace this list by the items of another list (theOther parameter). This method does not change the internal allocator.
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear this list
        """
    def Extent(self) -> int: ...
    def First(self) -> CDM_Reference: 
        """
        First item

        First item (non-const)
        """
    @overload
    def InsertAfter(self,theItem : CDM_Reference,theIter : Any) -> CDM_Reference: 
        """
        InsertAfter

        InsertAfter
        """
    @overload
    def InsertAfter(self,theOther : CDM_ListOfReferences,theIter : Any) -> None: ...
    @overload
    def InsertBefore(self,theItem : CDM_Reference,theIter : Any) -> CDM_Reference: 
        """
        InsertBefore

        InsertBefore
        """
    @overload
    def InsertBefore(self,theOther : CDM_ListOfReferences,theIter : Any) -> None: ...
    def IsEmpty(self) -> bool: ...
    def Last(self) -> CDM_Reference: 
        """
        Last item

        Last item (non-const)
        """
    @overload
    def Prepend(self,theItem : CDM_Reference) -> CDM_Reference: 
        """
        Prepend one item at the beginning

        Prepend another list at the beginning
        """
    @overload
    def Prepend(self,theOther : CDM_ListOfReferences) -> None: ...
    def Remove(self,theIter : Any) -> None: 
        """
        Remove item pointed by iterator theIter; theIter is then set to the next item
        """
    def RemoveFirst(self) -> None: 
        """
        RemoveFirst item
        """
    def Reverse(self) -> None: 
        """
        Reverse the list
        """
    def Size(self) -> int: 
        """
        Size - Number of items
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : CDM_ListOfReferences) -> None: ...
    def __iter__(self) -> Iterator[CDM_Reference]: ...
    def __len__(self) -> int: ...
    pass
class CDM_MapOfDocument(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: Single hashed Map. This Map is used to store and retrieve keys in linear time.
    """
    def Add(self,theKey : CDM_Document) -> bool: 
        """
        Add
        """
    def Added(self,theKey : CDM_Document) -> CDM_Document: 
        """
        Added: add a new key if not yet in the map, and return reference to either newly added or previously existing object
        """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : CDM_MapOfDocument) -> CDM_MapOfDocument: 
        """
        Assign. This method does not change the internal allocator.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def Contains(self,theKey : CDM_Document) -> bool: 
        """
        Contains

        Checks if this map contains all keys of another map. This function checks if this map contains all keys of another map.
        """
    @overload
    def Contains(self,theOther : CDM_MapOfDocument) -> bool: ...
    def Differ(self,theOther : CDM_MapOfDocument) -> bool: 
        """
        Apply to this Map the symmetric difference (aka exclusive disjunction, boolean XOR) operation with another (given) Map. The result contains the values that are contained only in this or the operand map, but not in both. This algorithm is similar to method Difference(). Returns True if contents of this map is changed.
        """
    def Difference(self,theLeft : CDM_MapOfDocument,theRight : CDM_MapOfDocument) -> None: 
        """
        Sets this Map to be the result of symmetric difference (aka exclusive disjunction, boolean XOR) operation between two given Maps. The new Map contains the values that are contained only in the first or the second operand maps but not in both. All previous content of this Map is cleared. This map (result of the boolean operation) can also be used as one of operands.
        """
    def Exchange(self,theOther : CDM_MapOfDocument) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    def HasIntersection(self,theMap : CDM_MapOfDocument) -> bool: 
        """
        Returns true if this and theMap have common elements.
        """
    def Intersect(self,theOther : CDM_MapOfDocument) -> bool: 
        """
        Apply to this Map the intersection operation (aka multiplication, common, boolean AND) with another (given) Map. The result contains only the values that are contained in both this and the given maps. This algorithm is similar to method Intersection(). Returns True if contents of this map is changed.
        """
    def Intersection(self,theLeft : CDM_MapOfDocument,theRight : CDM_MapOfDocument) -> None: 
        """
        Sets this Map to be the result of intersection (aka multiplication, common, boolean AND) operation between two given Maps. The new Map contains only the values that are contained in both map operands. All previous content of this Map is cleared. This same map (result of the boolean operation) can also be used as one of operands.
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def IsEqual(self,theOther : CDM_MapOfDocument) -> bool: 
        """
        Checks if two maps contain exactly the same keys. This function compares the keys of this map and another map and returns true if they contain exactly the same keys.
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Remove(self,K : CDM_Document) -> bool: 
        """
        Remove
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def Subtract(self,theOther : CDM_MapOfDocument) -> bool: 
        """
        Apply to this Map the subtraction (aka set-theoretic difference, relative complement, exclude, cut, boolean NOT) operation with another (given) Map. The result contains only the values that were previously contained in this map and not contained in this map. This algorithm is similar to method Subtract() with two operands. Returns True if contents of this map is changed.
        """
    def Subtraction(self,theLeft : CDM_MapOfDocument,theRight : CDM_MapOfDocument) -> None: 
        """
        Sets this Map to be the result of subtraction (aka set-theoretic difference, relative complement, exclude, cut, boolean NOT) operation between two given Maps. The new Map contains only the values that are contained in the first map operands and not contained in the second one. All previous content of this Map is cleared.
        """
    def Union(self,theLeft : CDM_MapOfDocument,theRight : CDM_MapOfDocument) -> None: 
        """
        Sets this Map to be the result of union (aka addition, fuse, merge, boolean OR) operation between two given Maps The new Map contains the values that are contained either in the first map or in the second map or in both. All previous content of this Map is cleared. This map (result of the boolean operation) can also be passed as one of operands.
        """
    def Unite(self,theOther : CDM_MapOfDocument) -> bool: 
        """
        Apply to this Map the boolean operation union (aka addition, fuse, merge, boolean OR) with another (given) Map. The result contains the values that were previously contained in this map or contained in the given (operand) map. This algorithm is similar to method Union(). Returns True if contents of this map is changed.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : CDM_MapOfDocument) -> None: ...
    def __iter__(self) -> Iterator[CDM_Document]: ...
    def __len__(self) -> int: ...
    pass
class CDM_MetaData(OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def Document(self) -> CDM_Document: ...
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def FileName(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def Folder(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        returns the folder in which the meta-data has to be created or has to be found.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasVersion(self) -> bool: 
        """
        indicates that the version has to be taken into account when searching the corresponding meta-data.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsReadOnly(self) -> bool: ...
    def IsRetrieved(self) -> bool: ...
    @staticmethod
    @overload
    def LookUp_s(theLookUpTable : Any,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aPath : OCP.TCollection.TCollection_ExtendedString,aFileName : OCP.TCollection.TCollection_ExtendedString,ReadOnly : bool) -> CDM_MetaData: ...
    @staticmethod
    @overload
    def LookUp_s(theLookUpTable : Any,aFolder : OCP.TCollection.TCollection_ExtendedString,aName : OCP.TCollection.TCollection_ExtendedString,aPath : OCP.TCollection.TCollection_ExtendedString,aVersion : OCP.TCollection.TCollection_ExtendedString,aFileName : OCP.TCollection.TCollection_ExtendedString,ReadOnly : bool) -> CDM_MetaData: ...
    def Name(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        returns the name under which the meta-data has to be created or has to be found.
        """
    def Path(self) -> OCP.TCollection.TCollection_ExtendedString: ...
    def Print(self,anOStream : io.BytesIO) -> io.BytesIO: ...
    def SetIsReadOnly(self) -> None: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def UnsetDocument(self) -> None: ...
    def UnsetIsReadOnly(self) -> None: ...
    def Version(self) -> OCP.TCollection.TCollection_ExtendedString: 
        """
        returns the version under which the meta-data has to be found. Warning: raises NoSuchObject from Standard if no Version has been defined
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDM_Reference(OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DocumentVersion(self) -> int: ...
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def FromDocument(self) -> CDM_Document: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsReadOnly(self) -> bool: ...
    def ReferenceIdentifier(self) -> int: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def ToDocument(self) -> CDM_Document: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class CDM_ReferenceIterator():
    def Document(self) -> CDM_Document: ...
    def DocumentVersion(self) -> int: 
        """
        returns the Document Version in the reference.
        """
    def More(self) -> bool: ...
    def Next(self) -> None: ...
    def ReferenceIdentifier(self) -> int: ...
    def __init__(self,aDocument : CDM_Document) -> None: ...
    pass
CDM_CCS_ModifiedReferenced: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_ModifiedReferenced: 3>
CDM_CCS_NotOpen: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_NotOpen: 1>
CDM_CCS_OK: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_OK: 0>
CDM_CCS_ReferenceRejection: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_ReferenceRejection: 4>
CDM_CCS_UnstoredReferenced: OCP.CDM.CDM_CanCloseStatus # value = <CDM_CanCloseStatus.CDM_CCS_UnstoredReferenced: 2>



import OCP.IGESConvGeom
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.IGESGeom
import OCP.Geom
import OCP.Geom2d
import OCP.gp
__all__  = [
"IGESConvGeom",
"IGESConvGeom_GeomBuilder"
]
class IGESConvGeom():
    """
    This package is intended to gather geometric conversion which are not immediate but can be used for several purposes : mainly, standard conversion to and from CasCade geometric and topologic data, and adaptations of IGES files as required (as replacing Spline entities to BSpline equivalents).
    """
    @staticmethod
    @overload
    def IncreaseCurveContinuity_s(curve : OCP.Geom.Geom_BSplineCurve,epsgeom : float,continuity : int=2) -> int: 
        """
        Tries to increase curve continuity with tolerance <epsgeom> <continuity> is the new desired continuity, can be 1 or 2 (more than 2 is considered as 2). Returns the new maximum continuity obtained on all knots. Remark that, for instance with <continuity> = 2, even if not all the knots can be passed to C2, all knots which can be are.
        """
    @staticmethod
    @overload
    def IncreaseCurveContinuity_s(curve : OCP.Geom2d.Geom2d_BSplineCurve,epsgeom : float,continuity : int=2) -> int: ...
    @staticmethod
    def IncreaseSurfaceContinuity_s(surface : OCP.Geom.Geom_BSplineSurface,epsgeom : float,continuity : int=2) -> int: 
        """
        Tries to increase Surface continuity with tolerance <epsgeom> <continuity> is the new desired continuity, can be 1 or 2 (more than 2 is considered as 2). Returns the new maximum continuity obtained on all knots. Remark that, for instance with <continuity> = 2, even if not all the knots can be passed to C2, all knots which can be are.
        """
    @staticmethod
    def SplineCurveFromIGES_s(igesent : OCP.IGESGeom.IGESGeom_SplineCurve,epscoef : float,epsgeom : float,result : OCP.Geom.Geom_BSplineCurve) -> int: 
        """
        basic tool to build curves from IGESGeom (arrays of points, Transformations, evaluation of points in a datum) Converts a SplineCurve from IGES to a BSplineCurve from CasCade <epscoef> gives tolerance to consider coefficient to be nul <epsgeom> gives tolerance to consider poles to be equal The returned value is a status with these possible values : - 0 OK, done - 1 the result is not guaranteed to be C0 (with <epsgeom>) - 2 SplineType not processed (allowed : max 3) (no result produced) - 3 error during creation of control points (no result produced) - 4 polynomial equation is not correct (no result produced) - 5 less than one segment (no result produced)
        """
    @staticmethod
    def SplineSurfaceFromIGES_s(igesent : OCP.IGESGeom.IGESGeom_SplineSurface,epscoef : float,epsgeom : float,result : OCP.Geom.Geom_BSplineSurface) -> int: 
        """
        Converts a SplineSurface from IGES to a BSplineSurface from CasCade <epscoef> gives tolerance to consider coefficient to be nul <epsgeom> gives tolerance to consider poles to be equal The returned value is a status with these possible values : - 0 OK, done - 1 the result is not guaranteed to be C0 (with <epsgeom>) - 2 degree is not compatible with code boundary type (warning) but C0 is OK - 3 idem but C0 is not guaranteed (warning) - 4 degree has been determined to be nul, either in U or V (no result produced) - 5 less than one segment in U or V (no result produced)
        """
    def __init__(self) -> None: ...
    pass
class IGESConvGeom_GeomBuilder():
    """
    This class provides some useful basic tools to build IGESGeom curves, especially : define a curve in a plane in 3D space (ex. Circular or Conic arc, or Copious Data defined in 2D) make a CopiousData from a list of points/vectors
    """
    def AddVec(self,val : OCP.gp.gp_XYZ) -> None: 
        """
        Adds a Vector part to the list of points. It will be used for CopiousData, datatype=3, only. AddXY and AddXYZ consider a null vector part (0,0,0) AddVec adds to the last added XY or XYZ
        """
    def AddXY(self,val : OCP.gp.gp_XY) -> None: 
        """
        Adds a XY (Z=0) to the list of points
        """
    def AddXYZ(self,val : OCP.gp.gp_XYZ) -> None: 
        """
        Adds a XYZ to the list of points
        """
    def Clear(self) -> None: 
        """
        Clears list of Points/Vectors and data about Transformation
        """
    def EvalXYZ(self,val : OCP.gp.gp_XYZ) -> tuple[float, float, float]: 
        """
        Evaluates a XYZ value in the Position already defined. Returns the transformed coordinates. For a 2D definition, X,Y will then be used to define a XY and Z will be regarded as a Z Displacement (can be ignored)
        """
    def IsIdentity(self) -> bool: 
        """
        Returns True if the Position is Identity
        """
    def IsTranslation(self) -> bool: 
        """
        Returns True if the Position is a Translation only Remark : Identity and ZOnly will answer True
        """
    def IsZOnly(self) -> bool: 
        """
        Returns True if the Position corresponds to a Z-Displacement, i.e. is a Translation only, and only on Z Remark : Identity will answer True
        """
    def MakeCopiousData(self,datatype : int,polyline : bool=False) -> OCP.IGESGeom.IGESGeom_CopiousData: 
        """
        Makes a CopiousData with the list of recorded Points/Vectors according to <datatype>, which must be 1,2 or 3 If <polyline> is given True, the CopiousData is coded as a Polyline, but <datatype> must not be 3 <datatype> = 1 : Common Z is computed as average of all Z <datatype> = 1 or 2 : Vectors are ignored
        """
    def MakeTransformation(self,unit : float=1.0) -> OCP.IGESGeom.IGESGeom_TransformationMatrix: 
        """
        Returns the IGES Transformation which corresponds to the Position. Even if it is an Identity : IsIdentity should be tested first. <unit> is the unit value in which the model is created : it is used to convert translation part
        """
    def NbPoints(self) -> int: 
        """
        Returns the count of already recorded points
        """
    def Point(self,num : int) -> OCP.gp.gp_XYZ: 
        """
        Returns a point given its rank (if added as XY, Z will be 0)
        """
    def Position(self) -> OCP.gp.gp_Trsf: 
        """
        Returns the Position in which the method EvalXYZ will evaluate a XYZ. It can be regarded as defining a local system. It is initially set to Identity
        """
    @overload
    def SetPosition(self,pos : OCP.gp.gp_Trsf) -> None: 
        """
        Sets final position from an already defined Trsf

        Sets final position from an Ax3

        Sets final position from an Ax2

        Sets final position from an Ax1 (this means that origin point and Z-axis are defined, the other axes are defined arbitrarily)
        """
    @overload
    def SetPosition(self,pos : OCP.gp.gp_Ax3) -> None: ...
    @overload
    def SetPosition(self,pos : OCP.gp.gp_Ax2) -> None: ...
    @overload
    def SetPosition(self,pos : OCP.gp.gp_Ax1) -> None: ...
    def __init__(self) -> None: ...
    pass



import OCP.BiTgte
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
import OCP.Geom
import OCP.TopTools
import OCP.TColStd
import OCP.TopoDS
import OCP.Standard
import OCP.GeomAbs
import OCP.Geom2d
import OCP.Adaptor3d
__all__  = [
"BiTgte_Blend",
"BiTgte_ContactType",
"BiTgte_CurveOnEdge",
"BiTgte_CurveOnVertex",
"BiTgte_EdgeEdge",
"BiTgte_EdgeVertex",
"BiTgte_FaceEdge",
"BiTgte_FaceFace",
"BiTgte_FaceVertex",
"BiTgte_VertexVertex"
]
class BiTgte_Blend():
    """
    Root class
    """
    def CenterLines(self,LC : OCP.TopTools.TopTools_ListOfShape) -> None: 
        """
        set in <LC> all the center lines
        """
    def Clear(self) -> None: 
        """
        Clear all the Fields.
        """
    def ComputeCenters(self) -> None: 
        """
        Computes the center lines
        """
    def ContactType(self,Index : int) -> BiTgte_ContactType: 
        """
        returns the type of contact
        """
    def CurveOnShape1(self,Index : int) -> OCP.Geom.Geom_Curve: 
        """
        gives the 3d curve of SurfaceFillet(Index) on SupportShape1(Index)
        """
    def CurveOnShape2(self,Index : int) -> OCP.Geom.Geom_Curve: 
        """
        gives the 3d curve of SurfaceFillet(Index) on SupportShape2(Index)
        """
    @overload
    def Face(self,Index : int) -> OCP.TopoDS.TopoDS_Face: 
        """
        returns the surface of range Index

        returns the face generated by the centerline. <CenterLine> may be - an edge : generate a pipe. - a vertex : generate a sphere. Warning: returns a Null Shape if <CenterLine> generates no surface.
        """
    @overload
    def Face(self,CenterLine : OCP.TopoDS.TopoDS_Shape) -> OCP.TopoDS.TopoDS_Face: ...
    def IndicesOfBranche(self,Index : int) -> tuple[int, int]: 
        """
        Set in <From>,<To> the indices of the faces of the branche <Index>.
        """
    def Init(self,S : OCP.TopoDS.TopoDS_Shape,Radius : float,Tol : float,NUBS : bool) -> None: ...
    def IsDone(self) -> bool: ...
    def NbBranches(self) -> int: ...
    def NbSurfaces(self) -> int: 
        """
        returns the Number of generated surfaces.
        """
    def PCurve1OnFillet(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnShape1(Index) on the Fillet
        """
    def PCurve2OnFillet(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnShape2(Index) on the fillet
        """
    def PCurveOnFace1(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurvOnShape1(Index) on the support face Warning: returns a Null Handle if SupportShape1 is not a Face
        """
    def PCurveOnFace2(self,Index : int) -> OCP.Geom2d.Geom2d_Curve: 
        """
        gives the PCurve associated to CurveOnShape2(Index) on the support face Warning: returns a Null Handle if SupportShape2 is not a Face
        """
    def Perform(self,BuildShape : bool=True) -> None: 
        """
        Compute the generated surfaces. If <BuildShape> is true, compute the resulting Shape. If false, only the blending surfaces are computed.
        """
    def SetEdge(self,Edge : OCP.TopoDS.TopoDS_Edge) -> None: 
        """
        Set an edge of <myShape> to be rounded.
        """
    def SetFaces(self,F1 : OCP.TopoDS.TopoDS_Face,F2 : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Set two faces of <myShape> on which the Sphere must roll.
        """
    def SetStoppingFace(self,Face : OCP.TopoDS.TopoDS_Face) -> None: 
        """
        Set a face on which the fillet must stop.
        """
    def Shape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        returns the result
        """
    def SupportShape1(self,Index : int) -> OCP.TopoDS.TopoDS_Shape: 
        """
        gives the first support shape relative to SurfaceFillet(Index);
        """
    def SupportShape2(self,Index : int) -> OCP.TopoDS.TopoDS_Shape: 
        """
        gives the second support shape relative to SurfaceFillet(Index);
        """
    @overload
    def Surface(self,Index : int) -> OCP.Geom.Geom_Surface: 
        """
        returns the surface of range Index

        returns the surface generated by the centerline. <CenterLine> may be - an edge : generate a pipe. - a vertex : generate a sphere. Warning: returns a Null Handle if <CenterLine> generates no surface.
        """
    @overload
    def Surface(self,CenterLine : OCP.TopoDS.TopoDS_Shape) -> OCP.Geom.Geom_Surface: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,S : OCP.TopoDS.TopoDS_Shape,Radius : float,Tol : float,NUBS : bool) -> None: ...
    pass
class BiTgte_ContactType():
    """
    Members:

      BiTgte_FaceFace

      BiTgte_FaceEdge

      BiTgte_FaceVertex

      BiTgte_EdgeEdge

      BiTgte_EdgeVertex

      BiTgte_VertexVertex
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    BiTgte_EdgeEdge: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_EdgeEdge: 3>
    BiTgte_EdgeVertex: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_EdgeVertex: 4>
    BiTgte_FaceEdge: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_FaceEdge: 1>
    BiTgte_FaceFace: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_FaceFace: 0>
    BiTgte_FaceVertex: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_FaceVertex: 2>
    BiTgte_VertexVertex: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_VertexVertex: 5>
    __entries: dict # value = {'BiTgte_FaceFace': (<BiTgte_ContactType.BiTgte_FaceFace: 0>, None), 'BiTgte_FaceEdge': (<BiTgte_ContactType.BiTgte_FaceEdge: 1>, None), 'BiTgte_FaceVertex': (<BiTgte_ContactType.BiTgte_FaceVertex: 2>, None), 'BiTgte_EdgeEdge': (<BiTgte_ContactType.BiTgte_EdgeEdge: 3>, None), 'BiTgte_EdgeVertex': (<BiTgte_ContactType.BiTgte_EdgeVertex: 4>, None), 'BiTgte_VertexVertex': (<BiTgte_ContactType.BiTgte_VertexVertex: 5>, None)}
    __members__: dict # value = {'BiTgte_FaceFace': <BiTgte_ContactType.BiTgte_FaceFace: 0>, 'BiTgte_FaceEdge': <BiTgte_ContactType.BiTgte_FaceEdge: 1>, 'BiTgte_FaceVertex': <BiTgte_ContactType.BiTgte_FaceVertex: 2>, 'BiTgte_EdgeEdge': <BiTgte_ContactType.BiTgte_EdgeEdge: 3>, 'BiTgte_EdgeVertex': <BiTgte_ContactType.BiTgte_EdgeVertex: 4>, 'BiTgte_VertexVertex': <BiTgte_ContactType.BiTgte_VertexVertex: 5>}
    pass
class BiTgte_CurveOnEdge(OCP.Adaptor3d.Adaptor3d_Curve, OCP.Standard.Standard_Transient):
    """
    private class used to create a filler rolling on an edge.private class used to create a filler rolling on an edge.
    """
    def BSpline(self) -> OCP.Geom.Geom_BSplineCurve: ...
    def Bezier(self) -> OCP.Geom.Geom_BezierCurve: ...
    def Circle(self) -> OCP.gp.gp_Circ: ...
    def Continuity(self) -> OCP.GeomAbs.GeomAbs_Shape: ...
    def D0(self,U : float,P : OCP.gp.gp_Pnt) -> None: 
        """
        Computes the point of parameter U on the curve.
        """
    def D1(self,U : float,P : OCP.gp.gp_Pnt,V : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point of parameter U on the curve with its first derivative. Raised if the continuity of the current interval is not C1.
        """
    def D2(self,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: 
        """
        Returns the point P of parameter U, the first and second derivatives V1 and V2. Raised if the continuity of the current interval is not C2.
        """
    def D3(self,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: 
        """
        Returns the point P of parameter U, the first, the second and the third derivative. Raised if the continuity of the current interval is not C3.
        """
    def DN(self,U : float,N : int) -> OCP.gp.gp_Vec: 
        """
        The returned vector gives the value of the derivative for the order of derivation N. Raised if the continuity of the current interval is not CN. Raised if N < 1.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Degree(self) -> int: ...
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Ellipse(self) -> OCP.gp.gp_Elips: ...
    def FirstParameter(self) -> float: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetType(self) -> OCP.GeomAbs.GeomAbs_CurveType: 
        """
        Returns the type of the curve in the current interval : Line, Circle, Ellipse, Hyperbola, Parabola, BezierCurve, BSplineCurve, OtherCurve.
        """
    def Hyperbola(self) -> OCP.gp.gp_Hypr: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,EonF : OCP.TopoDS.TopoDS_Edge,Edge : OCP.TopoDS.TopoDS_Edge) -> None: ...
    def Intervals(self,T : OCP.TColStd.TColStd_Array1OfReal,S : OCP.GeomAbs.GeomAbs_Shape) -> None: 
        """
        Stores in <T> the parameters bounding the intervals of continuity <S>.
        """
    def IsClosed(self) -> bool: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsPeriodic(self) -> bool: ...
    def IsRational(self) -> bool: ...
    def LastParameter(self) -> float: ...
    def Line(self) -> OCP.gp.gp_Lin: ...
    def NbIntervals(self,S : OCP.GeomAbs.GeomAbs_Shape) -> int: 
        """
        Returns the number of intervals for continuity <S>. May be one if Continuity(me) >= <S>
        """
    def NbKnots(self) -> int: ...
    def NbPoles(self) -> int: ...
    def OffsetCurve(self) -> OCP.Geom.Geom_OffsetCurve: ...
    def Parabola(self) -> OCP.gp.gp_Parab: ...
    def Period(self) -> float: ...
    def Resolution(self,R3d : float) -> float: 
        """
        Returns the parametric resolution corresponding to the real space resolution <R3d>.
        """
    def ShallowCopy(self) -> OCP.Adaptor3d.Adaptor3d_Curve: 
        """
        Shallow copy of adaptor
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Trim(self,First : float,Last : float,Tol : float) -> OCP.Adaptor3d.Adaptor3d_Curve: 
        """
        Returns a curve equivalent of <me> between parameters <First> and <Last>. <Tol> is used to test for 3d points confusion. If <First> >= <Last>
        """
    def Value(self,U : float) -> OCP.gp.gp_Pnt: 
        """
        Computes the point of parameter U on the curve.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,EonF : OCP.TopoDS.TopoDS_Edge,Edge : OCP.TopoDS.TopoDS_Edge) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class BiTgte_CurveOnVertex(OCP.Adaptor3d.Adaptor3d_Curve, OCP.Standard.Standard_Transient):
    """
    private class used to create a filler rolling on an edge.private class used to create a filler rolling on an edge.
    """
    def BSpline(self) -> OCP.Geom.Geom_BSplineCurve: ...
    def Bezier(self) -> OCP.Geom.Geom_BezierCurve: ...
    def Circle(self) -> OCP.gp.gp_Circ: ...
    def Continuity(self) -> OCP.GeomAbs.GeomAbs_Shape: ...
    def D0(self,U : float,P : OCP.gp.gp_Pnt) -> None: 
        """
        Computes the point of parameter U on the curve.
        """
    def D1(self,U : float,P : OCP.gp.gp_Pnt,V : OCP.gp.gp_Vec) -> None: 
        """
        Computes the point of parameter U on the curve with its first derivative. Raised if the continuity of the current interval is not C1.
        """
    def D2(self,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: 
        """
        Returns the point P of parameter U, the first and second derivatives V1 and V2. Raised if the continuity of the current interval is not C2.
        """
    def D3(self,U : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: 
        """
        Returns the point P of parameter U, the first, the second and the third derivative. Raised if the continuity of the current interval is not C3.
        """
    def DN(self,U : float,N : int) -> OCP.gp.gp_Vec: 
        """
        The returned vector gives the value of the derivative for the order of derivation N. Raised if the continuity of the current interval is not CN. Raised if N < 1.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Degree(self) -> int: ...
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Ellipse(self) -> OCP.gp.gp_Elips: ...
    def FirstParameter(self) -> float: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def GetType(self) -> OCP.GeomAbs.GeomAbs_CurveType: 
        """
        Returns the type of the curve in the current interval : Line, Circle, Ellipse, Hyperbola, Parabola, BezierCurve, BSplineCurve, OtherCurve.
        """
    def Hyperbola(self) -> OCP.gp.gp_Hypr: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def Init(self,EonF : OCP.TopoDS.TopoDS_Edge,V : OCP.TopoDS.TopoDS_Vertex) -> None: ...
    def Intervals(self,T : OCP.TColStd.TColStd_Array1OfReal,S : OCP.GeomAbs.GeomAbs_Shape) -> None: 
        """
        Stores in <T> the parameters bounding the intervals of continuity <S>.
        """
    def IsClosed(self) -> bool: ...
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsPeriodic(self) -> bool: ...
    def IsRational(self) -> bool: ...
    def LastParameter(self) -> float: ...
    def Line(self) -> OCP.gp.gp_Lin: ...
    def NbIntervals(self,S : OCP.GeomAbs.GeomAbs_Shape) -> int: 
        """
        Returns the number of intervals for continuity <S>. May be one if Continuity(me) >= <S>
        """
    def NbKnots(self) -> int: ...
    def NbPoles(self) -> int: ...
    def OffsetCurve(self) -> OCP.Geom.Geom_OffsetCurve: ...
    def Parabola(self) -> OCP.gp.gp_Parab: ...
    def Period(self) -> float: ...
    def Resolution(self,R3d : float) -> float: 
        """
        Returns the parametric resolution corresponding to the real space resolution <R3d>.
        """
    def ShallowCopy(self) -> OCP.Adaptor3d.Adaptor3d_Curve: 
        """
        Shallow copy of adaptor
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Trim(self,First : float,Last : float,Tol : float) -> OCP.Adaptor3d.Adaptor3d_Curve: 
        """
        Returns a curve equivalent of <me> between parameters <First> and <Last>. <Tol> is used to test for 3d points confusion. If <First> >= <Last>
        """
    def Value(self,U : float) -> OCP.gp.gp_Pnt: 
        """
        Computes the point of parameter U on the curve.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,EonF : OCP.TopoDS.TopoDS_Edge,V : OCP.TopoDS.TopoDS_Vertex) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
BiTgte_EdgeEdge: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_EdgeEdge: 3>
BiTgte_EdgeVertex: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_EdgeVertex: 4>
BiTgte_FaceEdge: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_FaceEdge: 1>
BiTgte_FaceFace: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_FaceFace: 0>
BiTgte_FaceVertex: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_FaceVertex: 2>
BiTgte_VertexVertex: OCP.BiTgte.BiTgte_ContactType # value = <BiTgte_ContactType.BiTgte_VertexVertex: 5>



import OCP.TopLoc
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.Standard
import io
import OCP.gp
import OCP.NCollection
__all__  = [
"TopLoc_Datum3D",
"TopLoc_IndexedMapOfLocation",
"TopLoc_ItemLocation",
"TopLoc_Location",
"TopLoc_MapOfLocation",
"TopLoc_SListNodeOfItemLocation",
"TopLoc_SListOfItemLocation",
"ShallowDump"
]
class TopLoc_Datum3D(OCP.Standard.Standard_Transient):
    """
    Describes a coordinate transformation, i.e. a change to an elementary 3D coordinate system, or position in 3D space. A Datum3D is always described relative to the default datum. The default datum is described relative to itself: its origin is (0,0,0), and its axes are (1,0,0) (0,1,0) (0,0,1).Describes a coordinate transformation, i.e. a change to an elementary 3D coordinate system, or position in 3D space. A Datum3D is always described relative to the default datum. The default datum is described relative to itself: its origin is (0,0,0), and its axes are (1,0,0) (0,1,0) (0,0,1).Describes a coordinate transformation, i.e. a change to an elementary 3D coordinate system, or position in 3D space. A Datum3D is always described relative to the default datum. The default datum is described relative to itself: its origin is (0,0,0), and its axes are (1,0,0) (0,1,0) (0,0,1).
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Form(self) -> OCP.gp.gp_TrsfForm: 
        """
        Return transformation form.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def ShallowDump(self,S : io.BytesIO) -> None: 
        """
        Writes the contents of this Datum3D to the stream S.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Transformation(self) -> OCP.gp.gp_Trsf: 
        """
        Returns a gp_Trsf which, when applied to this datum, produces the default datum.
        """
    def Trsf(self) -> OCP.gp.gp_Trsf: 
        """
        Returns a gp_Trsf which, when applied to this datum, produces the default datum.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,T : OCP.gp.gp_Trsf) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TopLoc_IndexedMapOfLocation(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: An indexed map is used to store keys and to bind an index to them. Each new key stored in the map gets an index. Index are incremented as keys are stored in the map. A key can be found by the index and an index by the key. No key but the last can be removed so the indices are in the range 1..Extent. See the class Map from NCollection for a discussion about the number of buckets.
    """
    def Add(self,theKey1 : TopLoc_Location) -> int: 
        """
        Add
        """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : TopLoc_IndexedMapOfLocation) -> TopLoc_IndexedMapOfLocation: 
        """
        Assign. This method does not change the internal allocator.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    def Contains(self,theKey1 : TopLoc_Location) -> bool: 
        """
        Contains
        """
    def Exchange(self,theOther : TopLoc_IndexedMapOfLocation) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    def FindIndex(self,theKey1 : TopLoc_Location) -> int: 
        """
        FindIndex
        """
    def FindKey(self,theIndex : int) -> TopLoc_Location: 
        """
        FindKey
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,theExtent : int) -> None: 
        """
        ReSize
        """
    def RemoveFromIndex(self,theIndex : int) -> None: 
        """
        Remove the key of the given index. Caution! The index of the last key can be changed.
        """
    def RemoveKey(self,theKey1 : TopLoc_Location) -> bool: 
        """
        Remove the given key. Caution! The index of the last key can be changed.
        """
    def RemoveLast(self) -> None: 
        """
        RemoveLast
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def Substitute(self,theIndex : int,theKey1 : TopLoc_Location) -> None: 
        """
        Substitute
        """
    def Swap(self,theIndex1 : int,theIndex2 : int) -> None: 
        """
        Swaps two elements with the given indices.
        """
    def __call__(self,theIndex : int) -> TopLoc_Location: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : TopLoc_IndexedMapOfLocation) -> None: ...
    def __iter__(self) -> Iterator[TopLoc_Location]: ...
    def __len__(self) -> int: ...
    pass
class TopLoc_ItemLocation():
    """
    An ItemLocation is an elementary coordinate system in a Location.
    """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def __init__(self,D : TopLoc_Datum3D,P : int) -> None: ...
    pass
class TopLoc_Location():
    """
    A Location is a composite transition. It comprises a series of elementary reference coordinates, i.e. objects of type TopLoc_Datum3D, and the powers to which these objects are raised.
    """
    def Clear(self) -> None: 
        """
        Clear myItems
        """
    def Divided(self,Other : TopLoc_Location) -> TopLoc_Location: 
        """
        Returns <me> / <Other>.
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def FirstDatum(self) -> TopLoc_Datum3D: 
        """
        Returns the first elementary datum of the Location. Use the NextLocation function recursively to access the other data comprising this location. Exceptions Standard_NoSuchObject if this location is empty.

        Returns the first elementary datum of the Location. Use the NextLocation function recursively to access the other data comprising this location. Exceptions Standard_NoSuchObject if this location is empty.
        """
    def FirstPower(self) -> int: 
        """
        Returns the power elevation of the first elementary datum. Exceptions Standard_NoSuchObject if this location is empty.

        Returns the power elevation of the first elementary datum. Exceptions Standard_NoSuchObject if this location is empty.
        """
    def HashCode(self) -> int: 
        """
        Returns a hashed value for this local coordinate system. This value is used, with map tables, to store and retrieve the object easily

        Returns a hashed value for this local coordinate system. This value is used, with map tables, to store and retrieve the object easily
        """
    def Identity(self) -> None: 
        """
        Resets this location to the Identity transformation.

        Resets this location to the Identity transformation.
        """
    def Inverted(self) -> TopLoc_Location: 
        """
        Returns the inverse of <me>.
        """
    def IsDifferent(self,Other : TopLoc_Location) -> bool: 
        """
        Returns true if this location and the location Other do not have the same elementary data, i.e. do not contain the same series of TopLoc_Datum3D and respective powers. This method is an alias for operator !=.
        """
    def IsEqual(self,Other : TopLoc_Location) -> bool: 
        """
        Returns true if this location and the location Other have the same elementary data, i.e. contain the same series of TopLoc_Datum3D and respective powers. This method is an alias for operator ==.
        """
    def IsIdentity(self) -> bool: 
        """
        Returns true if this location is equal to the Identity transformation.

        Returns true if this location is equal to the Identity transformation.
        """
    def Multiplied(self,Other : TopLoc_Location) -> TopLoc_Location: 
        """
        Returns <me> * <Other>, the elementary datums are concatenated.
        """
    def NextLocation(self) -> TopLoc_Location: 
        """
        Returns a Location representing <me> without the first datum. We have the relation :

        Returns a Location representing <me> without the first datum. We have the relation :
        """
    def Powered(self,pwr : int) -> TopLoc_Location: 
        """
        Returns me at the power <pwr>. If <pwr> is zero returns Identity. <pwr> can be lower than zero (usual meaning for powers).
        """
    def Predivided(self,Other : TopLoc_Location) -> TopLoc_Location: 
        """
        Returns <Other>.Inverted() * <me>.
        """
    @staticmethod
    def ScalePrec_s() -> float: ...
    def ShallowDump(self,S : io.BytesIO) -> None: 
        """
        Prints the contents of <me> on the stream .
        """
    def Transformation(self) -> OCP.gp.gp_Trsf: 
        """
        Returns the transformation associated to the coordinate system.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,T : OCP.gp.gp_Trsf) -> None: ...
    @overload
    def __init__(self,D : TopLoc_Datum3D) -> None: ...
    def __mul__(self,Other : TopLoc_Location) -> TopLoc_Location: ...
    def __rmul__(self,Other : TopLoc_Location) -> TopLoc_Location: ...
    def __truediv__(self,Other : TopLoc_Location) -> TopLoc_Location: ...
    pass
class TopLoc_MapOfLocation(OCP.NCollection.NCollection_BaseMap):
    """
    Purpose: Single hashed Map. This Map is used to store and retrieve keys in linear time.
    """
    def Add(self,theKey : TopLoc_Location) -> bool: 
        """
        Add
        """
    def Added(self,theKey : TopLoc_Location) -> TopLoc_Location: 
        """
        Added: add a new key if not yet in the map, and return reference to either newly added or previously existing object
        """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    def Assign(self,theOther : TopLoc_MapOfLocation) -> TopLoc_MapOfLocation: 
        """
        Assign. This method does not change the internal allocator.
        """
    @overload
    def Clear(self,doReleaseMemory : bool=False) -> None: 
        """
        Clear data. If doReleaseMemory is false then the table of buckets is not released and will be reused.

        Clear data and reset allocator
        """
    @overload
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def Contains(self,theKey : TopLoc_Location) -> bool: 
        """
        Contains

        Checks if this map contains all keys of another map. This function checks if this map contains all keys of another map.
        """
    @overload
    def Contains(self,theOther : TopLoc_MapOfLocation) -> bool: ...
    def Differ(self,theOther : TopLoc_MapOfLocation) -> bool: 
        """
        Apply to this Map the symmetric difference (aka exclusive disjunction, boolean XOR) operation with another (given) Map. The result contains the values that are contained only in this or the operand map, but not in both. This algorithm is similar to method Difference(). Returns True if contents of this map is changed.
        """
    def Difference(self,theLeft : TopLoc_MapOfLocation,theRight : TopLoc_MapOfLocation) -> None: 
        """
        Sets this Map to be the result of symmetric difference (aka exclusive disjunction, boolean XOR) operation between two given Maps. The new Map contains the values that are contained only in the first or the second operand maps but not in both. All previous content of this Map is cleared. This map (result of the boolean operation) can also be used as one of operands.
        """
    def Exchange(self,theOther : TopLoc_MapOfLocation) -> None: 
        """
        Exchange the content of two maps without re-allocations. Notice that allocators will be swapped as well!
        """
    def Extent(self) -> int: 
        """
        Extent
        """
    def HasIntersection(self,theMap : TopLoc_MapOfLocation) -> bool: 
        """
        Returns true if this and theMap have common elements.
        """
    def Intersect(self,theOther : TopLoc_MapOfLocation) -> bool: 
        """
        Apply to this Map the intersection operation (aka multiplication, common, boolean AND) with another (given) Map. The result contains only the values that are contained in both this and the given maps. This algorithm is similar to method Intersection(). Returns True if contents of this map is changed.
        """
    def Intersection(self,theLeft : TopLoc_MapOfLocation,theRight : TopLoc_MapOfLocation) -> None: 
        """
        Sets this Map to be the result of intersection (aka multiplication, common, boolean AND) operation between two given Maps. The new Map contains only the values that are contained in both map operands. All previous content of this Map is cleared. This same map (result of the boolean operation) can also be used as one of operands.
        """
    def IsEmpty(self) -> bool: 
        """
        IsEmpty
        """
    def IsEqual(self,theOther : TopLoc_MapOfLocation) -> bool: 
        """
        Checks if two maps contain exactly the same keys. This function compares the keys of this map and another map and returns true if they contain exactly the same keys.
        """
    def NbBuckets(self) -> int: 
        """
        NbBuckets
        """
    def ReSize(self,N : int) -> None: 
        """
        ReSize
        """
    def Remove(self,K : TopLoc_Location) -> bool: 
        """
        Remove
        """
    def Size(self) -> int: 
        """
        Size
        """
    def Statistics(self,S : io.BytesIO) -> None: 
        """
        Statistics
        """
    def Subtract(self,theOther : TopLoc_MapOfLocation) -> bool: 
        """
        Apply to this Map the subtraction (aka set-theoretic difference, relative complement, exclude, cut, boolean NOT) operation with another (given) Map. The result contains only the values that were previously contained in this map and not contained in this map. This algorithm is similar to method Subtract() with two operands. Returns True if contents of this map is changed.
        """
    def Subtraction(self,theLeft : TopLoc_MapOfLocation,theRight : TopLoc_MapOfLocation) -> None: 
        """
        Sets this Map to be the result of subtraction (aka set-theoretic difference, relative complement, exclude, cut, boolean NOT) operation between two given Maps. The new Map contains only the values that are contained in the first map operands and not contained in the second one. All previous content of this Map is cleared.
        """
    def Union(self,theLeft : TopLoc_MapOfLocation,theRight : TopLoc_MapOfLocation) -> None: 
        """
        Sets this Map to be the result of union (aka addition, fuse, merge, boolean OR) operation between two given Maps The new Map contains the values that are contained either in the first map or in the second map or in both. All previous content of this Map is cleared. This map (result of the boolean operation) can also be passed as one of operands.
        """
    def Unite(self,theOther : TopLoc_MapOfLocation) -> bool: 
        """
        Apply to this Map the boolean operation union (aka addition, fuse, merge, boolean OR) with another (given) Map. The result contains the values that were previously contained in this map or contained in the given (operand) map. This algorithm is similar to method Union(). Returns True if contents of this map is changed.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theNbBuckets : int,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: ...
    @overload
    def __init__(self,theOther : TopLoc_MapOfLocation) -> None: ...
    def __iter__(self) -> Iterator[TopLoc_Location]: ...
    def __len__(self) -> int: ...
    pass
class TopLoc_SListNodeOfItemLocation(OCP.Standard.Standard_Transient):
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def Tail(self) -> TopLoc_SListOfItemLocation: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Value(self) -> TopLoc_ItemLocation: ...
    def __init__(self,I : TopLoc_ItemLocation,aTail : TopLoc_SListOfItemLocation) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TopLoc_SListOfItemLocation():
    """
    An SListOfItemLocation is a LISP like list of Items. An SListOfItemLocation is : . Empty. . Or it has a Value and a Tail which is an other SListOfItemLocation.
    """
    def Assign(self,Other : TopLoc_SListOfItemLocation) -> TopLoc_SListOfItemLocation: 
        """
        Sets a list from an other one. The lists are shared. The list itself is returned.
        """
    def Clear(self) -> None: 
        """
        Sets the list to be empty.
        """
    def Construct(self,anItem : TopLoc_ItemLocation) -> None: 
        """
        Replaces the list by a list with <anItem> as Value and the list <me> as tail.
        """
    def IsEmpty(self) -> bool: 
        """
        Return true if this list is empty
        """
    def More(self) -> bool: 
        """
        Returns True if the iterator has a current value. This is !IsEmpty()
        """
    def Next(self) -> None: 
        """
        Moves the iterator to the next object in the list. If the iterator is empty it will stay empty. This is ToTail()
        """
    def Tail(self) -> TopLoc_SListOfItemLocation: 
        """
        Returns the current tail of the list. On an empty list the tail is the list itself.
        """
    def ToTail(self) -> None: 
        """
        Replaces the list <me> by its tail.
        """
    def Value(self) -> TopLoc_ItemLocation: 
        """
        Returns the current value of the list. An error is raised if the list is empty.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,anItem : TopLoc_ItemLocation,aTail : TopLoc_SListOfItemLocation) -> None: ...
    @overload
    def __init__(self,Other : TopLoc_SListOfItemLocation) -> None: ...
    pass
@overload
def ShallowDump(me : TopLoc_Datum3D,S : io.BytesIO) -> None:
    pass
@overload
def ShallowDump(me : TopLoc_Location,S : io.BytesIO) -> None:
    pass
